#!/bin/bash
#This script will help a deployment of a docker image on an MBB bigmem machine
if [ $# -lt 1 ]
then
    APP_IMG="mbbteam/rnaseqde:latest"  
else 
    IMG_SRC=$1
    case $IMG_SRC in
        docker )
            APP_IMG="mbbteam/rnaseqde:latest"  ;;
        local)
            docker build . -t rnaseqde:latest 
            APP_IMG="rnaseqde:latest" ;;
        mbb)    
            #APP_IMG="X.X.X.X:5000/rnaseqde:latest" ;;
    esac
fi


#nginx 

    APP_PORT=8787
    HTTP_ENDP="https://$HOST_NAME"

    openssl req -x509 -nodes -days 365 -newkey rsa:2048 -keyout /etc/ssl/private/nginx-selfsigned.key -out /etc/ssl/certs/nginx-selfsigned.crt -subj "/C=FR/ST=LR/L=Montpellier/O=CNRS/OU=CNRS-ISEM/CN=mbb.univ-montp2.fr"
    openssl dhparam -out /etc/ssl/certs/dhparam.pem 2048

    mkdir -p /etc/nginx/snippets
    echo "ssl_certificate /etc/ssl/certs/nginx-selfsigned.crt;" > /etc/nginx/snippets/self-signed.conf
    echo "ssl_certificate_key /etc/ssl/private/nginx-selfsigned.key;" >> /etc/nginx/snippets/self-signed.conf

    cp system/nginx_snippets_ssl-params.conf /etc/nginx/snippets/ssl-params.conf

    cp /etc/nginx/sites-available/default /etc/nginx/sites-available/default.bak

    cp system/nginx_sites-available_default /etc/nginx/sites-available/default
    sed -i "s|server_domain_or_IP|$HOST_NAME|"  /etc/nginx/sites-available/default

    useradd nginx
    cp system/nginx_nginx.conf /etc/nginx/nginx.conf

    cp system/nginx_conf.d_10-rstudio.conf /etc/nginx/conf.d/10-rstudio.conf
    sed -i "s|example.com|$HOST_NAME|" /etc/nginx/conf.d/10-rstudio.conf

    systemctl restart nginx
    systemctl enable nginx

#essayer une plage de ports entre 8787 et 8800
#APP_PORT=$2 
APP_PORT=8787
while [[ $(ss -tulw | grep $APP_PORT) != "" && $APP_PORT < 8800 ]]
do
  APP_PORT=$(( $APP_PORT + 1))
done

if [[ $(ss -tulw | grep $APP_PORT) != "" ]]
then
  echo "No tcp port available !!"
  exit -1
fi

# Docker volumes
#realUSER=$(who am i | awk '{print $1}')
if [ $SUDO_USER ]; then realUSER=$SUDO_USER; else realUSER=`whoami`; fi
VOL_DEV=/media/bigvol/$realUSER
# MBB Workflows reads data from /Data and write results to /Results
mkdir -p ${VOL_DEV}/Data
mkdir -p ${VOL_DEV}/Results
DOCK_VOL+=" --mount type=bind,src=$VOL_DEV/Data,dst=/Data"
DOCK_VOL+=" --mount type=bind,src=$VOL_DEV/Results,dst=/Results"


CONTAINER_ID=$( docker run --rm -d -p $APP_PORT:3838 $DOCK_VOL $APP_IMG )
if [ $CONTAINER_ID ]
then
    echo " "
    echo You have to put your Data on  : ${VOL_DEV}/Data
    echo " "
    echo Results will be written to    : ${VOL_DEV}/Results
    echo " "
    hostname -I | awk -v port=$APP_PORT '{print "You can access the workflow interface at :  http://"$1":"port}'
    echo " "
    echo To start a Bash session inside the container : docker exec -it $CONTAINER_ID /bin/bash
    echo " "
    echo To run the workflow without the interface : docker exec -it $CONTAINER_ID snakemake -s /workflow/Snakefile all --configfile config --cores XX
    echo " "
    echo config est un fichier de configuration qui doit être dans un sous dossier de ${VOL_DEV}/Data ou ${VOL_DEV}/Results
    echo " "
    echo ex. si fichier dans ${VOL_DEV}/Data/run1/maconfig1.yml : docker exec -it $CONTAINER_ID snakemake -s /workflow/Snakefile all --configfile /Data/run1/maconfig1.yml --cores XX
    echo " "
    echo Vous pouvez utiliser l''interface graphique pour générer un fichier de configuration.
    echo " "
    echo XX étant le nombre de coeurs qui seront utilisés par le workflow.
else
    echo Failed to run the docker container  !!
fi
